FiscalYearExt extension

Extension providing fiscal year calculations for Hora.

on

Methods

daysRemainingInFiscalQuarter({int startMonth = 1}) → int

Available on Hora, provided by the FiscalYearExt extension

Gets the number of days remaining in the fiscal quarter.
daysRemainingInFiscalYear({int startMonth = 1, int startDay = 1}) → int

Available on Hora, provided by the FiscalYearExt extension

Gets the number of days remaining in the fiscal year.
endOfFiscalQuarter({int startMonth = 1}) → Hora

Available on Hora, provided by the FiscalYearExt extension

Gets the end of the fiscal quarter.
endOfFiscalYear({int startMonth = 1, int startDay = 1}) → Hora

Available on Hora, provided by the FiscalYearExt extension

Gets the end of the fiscal year.
endOfFiscalYearWithConfig(FiscalYearConfig config) → Hora

Available on Hora, provided by the FiscalYearExt extension

Gets the end of the fiscal year using a configuration.
fiscalPeriod({FiscalYearConfig config = const FiscalYearConfig()}) → FiscalPeriod

Available on Hora, provided by the FiscalYearExt extension

Gets the complete fiscal period information.
fiscalQuarter({int startMonth = 1}) → int

Available on Hora, provided by the FiscalYearExt extension

Gets the fiscal quarter (1-4).
fiscalQuarterWithConfig(FiscalYearConfig config) → int

Available on Hora, provided by the FiscalYearExt extension

Gets the fiscal quarter using a configuration.
fiscalYear({int startMonth = 1, int yearOffset = 0}) → int

Available on Hora, provided by the FiscalYearExt extension

Gets the fiscal year for this date.
fiscalYearProgress({int startMonth = 1, int startDay = 1}) → double

Available on Hora, provided by the FiscalYearExt extension

Gets the progress through the fiscal year as a fraction (0.0 - 1.0).
fiscalYearWithConfig(FiscalYearConfig config) → int

Available on Hora, provided by the FiscalYearExt extension

Gets the fiscal year using a configuration.
isSameFiscalQuarter(Hora other, {int startMonth = 1}) → bool

Available on Hora, provided by the FiscalYearExt extension

Checks if this date is in the same fiscal quarter as another.
isSameFiscalYear(Hora other, {int startMonth = 1}) → bool

Available on Hora, provided by the FiscalYearExt extension

Checks if this date is in the same fiscal year as another.
startOfFiscalQuarter({int startMonth = 1}) → Hora

Available on Hora, provided by the FiscalYearExt extension

Gets the start of the fiscal quarter.
startOfFiscalYear({int startMonth = 1, int startDay = 1}) → Hora

Available on Hora, provided by the FiscalYearExt extension

Gets the start of the fiscal year.
startOfFiscalYearWithConfig(FiscalYearConfig config) → Hora

Available on Hora, provided by the FiscalYearExt extension

Gets the start of the fiscal year using a configuration.