HoraGetField enum
Type-safe fields for component reads.
Values
- year → const HoraGetField
- month → const HoraGetField
- day → const HoraGetField
- hour → const HoraGetField
- minute → const HoraGetField
- second → const HoraGetField
- millisecond → const HoraGetField
- microsecond → const HoraGetField
- weekday → const HoraGetField
- quarter → const HoraGetField
- dayOfYear → const HoraGetField
- isoWeek → const HoraGetField
- isoWeekYear → const HoraGetField
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HoraGetField> - A constant List of the values in this enum, in order of their declaration.