HoraObject class

Factory for creating Hora from maps.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(Map<String, Object?> map, {bool utc = false}) → Hora
Creates a Hora from a map of date-time components.
tryFrom(Map<String, Object?>? map, {bool utc = false}) → Hora?
Creates a Hora from a map, returning null if the map is empty.