HoraWeekExt extension

Week calculations for Hora.

Provides locale-aware and custom week numbering through a unified WeekConfig parameter. ISO 8601 week properties (isoWeek, isoWeekYear, isoWeeksInYear) are available directly on Hora.

on

Properties

daysOfIsoWeek List<Hora>

Available on Hora, provided by the HoraWeekExt extension

All 7 days in the current ISO week.
no setter
endOfIsoWeek Hora

Available on Hora, provided by the HoraWeekExt extension

The end of the current ISO week (Sunday 23:59:59.999999).
no setter
isoDayOfWeek int

Available on Hora, provided by the HoraWeekExt extension

The ISO day of the week (1 = Monday, 7 = Sunday).
no setter
localeWeek int

Available on Hora, provided by the HoraWeekExt extension

The locale-aware week number.
no setter
localeWeekYear int

Available on Hora, provided by the HoraWeekExt extension

The locale-aware week year.
no setter
startOfIsoWeek Hora

Available on Hora, provided by the HoraWeekExt extension

The start of the current ISO week (Monday 00:00:00.000000).
no setter
weekOfMonth int

Available on Hora, provided by the HoraWeekExt extension

The ordinal week of the month (1–5).
no setter

Methods

daysOfWeekWith({WeekConfig config = WeekConfig.iso}) List<Hora>

Available on Hora, provided by the HoraWeekExt extension

All 7 days in the current week.
endOfWeek({WeekConfig config = WeekConfig.iso}) Hora

Available on Hora, provided by the HoraWeekExt extension

The end of the current week at 23:59:59.999999.
isSameIsoWeek(Hora other) bool

Available on Hora, provided by the HoraWeekExt extension

Whether this date is in the same ISO week as other.
isSameWeek(Hora other, {WeekConfig config = WeekConfig.iso}) bool

Available on Hora, provided by the HoraWeekExt extension

Whether this date is in the same week as other.
setWeekOfYear(int week, {WeekConfig config = WeekConfig.iso}) Hora

Available on Hora, provided by the HoraWeekExt extension

Sets the week of year, returning a new Hora.
setWeekYear(int targetYear, {WeekConfig config = WeekConfig.iso}) Hora

Available on Hora, provided by the HoraWeekExt extension

Sets the week year, returning a new Hora.
startOfWeek({WeekConfig config = WeekConfig.iso}) Hora

Available on Hora, provided by the HoraWeekExt extension

The start of the current week at 00:00:00.000000.
weekOfYear({WeekConfig config = WeekConfig.iso}) int

Available on Hora, provided by the HoraWeekExt extension

The week number within the year (1–53).
weeksInYear({WeekConfig config = WeekConfig.iso}) int

Available on Hora, provided by the HoraWeekExt extension

The number of weeks in the specified year (52 or 53).
weekSpansMonths({WeekConfig config = WeekConfig.iso}) bool

Available on Hora, provided by the HoraWeekExt extension

Whether this week spans two calendar months.
weekSpansYears({WeekConfig config = WeekConfig.iso}) bool

Available on Hora, provided by the HoraWeekExt extension

Whether this week spans two calendar years.
weekYear({WeekConfig config = WeekConfig.iso}) int

Available on Hora, provided by the HoraWeekExt extension

The year to which the current week belongs.