weekYear method
The year to which the current week belongs.
This may differ from the calendar year near year boundaries.
Implementation
int weekYear({WeekConfig config = WeekConfig.iso}) {
_validateWeekConfig(config);
return _weekYear(config);
}
The year to which the current week belongs.
This may differ from the calendar year near year boundaries.
int weekYear({WeekConfig config = WeekConfig.iso}) {
_validateWeekConfig(config);
return _weekYear(config);
}