LocaleData class

Provides access to locale-specific data.

Available extensions

Properties

code → String
Gets the locale code.
no setter
firstDayOfWeek → int
Gets the first day of week in ISO weekday numbering (1 = Monday, 7 = Sunday).
no setter
hashCode → int
The hash code for this object.
no setterinherited
longDateFormat → String
Gets the long date format.
no setter
meridiem → List<String>
Gets the AM/PM designators.
no setter
monthEntries → Iterable<MapEntry<int, String>>

Available on LocaleData, provided by the LocaleIterationExt extension

Iterates over all months with their names.
no setter
monthEntriesShort → Iterable<MapEntry<int, String>>

Available on LocaleData, provided by the LocaleIterationExt extension

Iterates over all months with their short names.
no setter
months → List<String>
Gets the list of month names.
no setter
monthsShort → List<String>
Gets the list of short month names.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortDateFormat → String
Gets the short date format.
no setter
timeFormat → String
Gets the time format.
no setter
weekdayEntries → Iterable<MapEntry<int, String>>

Available on LocaleData, provided by the LocaleIterationExt extension

Iterates over all weekdays with their names.
no setter
weekdayEntriesShort → Iterable<MapEntry<int, String>>

Available on LocaleData, provided by the LocaleIterationExt extension

Iterates over all weekdays with their short names.
no setter
weekdays → List<String>
Gets the list of weekday names.
no setter
weekdaysMin → List<String>
Gets the list of minimal weekday names.
no setter
weekdaysShort → List<String>
Gets the list of short weekday names.
no setter

Methods

monthName(int month) → String
Gets the month name for a given month number (1-12).
monthNameShort(int month) → String
Gets the short month name for a given month number (1-12).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ordinal(int n) → String
Gets the ordinal suffix for a number.
toString() → String
A string representation of this object.
override
weekdayName(int weekday) → String
Gets the weekday name for a given day number (0 = Sunday).
weekdayNameShort(int weekday) → String
Gets the short weekday name for a given day number (0 = Sunday).

Operators

operator ==(Object other) → bool
The equality operator.
inherited