MinMaxExt extension

Extension providing min/max operations for Hora.

on

Methods

atLeast(Hora min) → Hora

Available on Hora, provided by the MinMaxExt extension

Ensures this date is not before the minimum.
atMost(Hora max) → Hora

Available on Hora, provided by the MinMaxExt extension

Ensures this date is not after the maximum.
clampBetween(Hora min, Hora max) → Hora

Available on Hora, provided by the MinMaxExt extension

Clamps this date to be within a range.
isStrictlyWithin(Hora start, Hora end) → bool

Available on Hora, provided by the MinMaxExt extension

Checks if this date is strictly within a range (exclusive).
isWithin(Hora start, Hora end) → bool

Available on Hora, provided by the MinMaxExt extension

Checks if this date is within a range (inclusive).
max(Hora other) → Hora

Available on Hora, provided by the MinMaxExt extension

Gets the later of this and another date.
min(Hora other) → Hora

Available on Hora, provided by the MinMaxExt extension

Gets the earlier of this and another date.