MinMaxResult class

Result containing both min and max values.

Constructors

MinMaxResult({required Hora min, required Hora max})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → Hora
The maximum value.
final
min → Hora
The minimum value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → Duration
The span between min and max.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited