MonthCalendar class

Represents a calendar month with weeks.

Properties

days → List<Hora>
Gets all days of the month.
no setter
firstDayOfWeek → int
The first day of the week (1 = Monday, 7 = Sunday).
final
hashCode → int
The hash code for this object.
no setterinherited
month → int
The month.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weekCount → int
Gets the number of weeks.
no setter
weeks → List<List<Hora?>>
The weeks of the calendar. Each week is a list of 7 dates (null for days outside the month).
final
year → int
The year.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited