Recurrence class abstract

Represents a recurrence rule for generating date sequences.

Inheritance
Available extensions

Properties

count → int?
The maximum number of occurrences (optional).
no setter
earliest → Hora?

Available on Iterable<Hora>, provided by the HoraMinMaxExt extension

Returns the earliest (minimum) Hora in this iterable.
no setter
end → Hora?
The ending date for the recurrence (optional).
no setter
first → Hora
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<Hora>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → Hora
The last element.
no setterinherited
latest → Hora?

Available on Iterable<Hora>, provided by the HoraMinMaxExt extension

Returns the latest (maximum) Hora in this iterable.
no setter
length → int
The number of elements in this Iterable.
no setterinherited
maxHora → Hora

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets the maximum date.
no setter
maxHoraOrNull → Hora?

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets the maximum date or null if empty.
no setter
medianHora → Hora?

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets the median date.
no setter
minHora → Hora

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets the minimum date.
no setter
minHoraOrNull → Hora?

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets the minimum date or null if empty.
no setter
minMaxHora → MinMaxResult

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets both min and max.
no setter
minMaxHoraOrNull → MinMaxResult?

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets both min and max or null if empty.
no setter
range → (Hora?, Hora?)

Available on Iterable<Hora>, provided by the HoraMinMaxExt extension

Returns the earliest and latest Hora as a range.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → Hora
Checks that this iterable has only one element, and returns that element.
no setterinherited
sortedChronologically → List<Hora>

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Sorts this iterable chronologically.
no setter
sortedReverseChronologically → List<Hora>

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Sorts this iterable reverse chronologically.
no setter
span → Duration

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets the span between the earliest and latest dates.
no setter
start → Hora
The starting date for the recurrence.
no setter

Methods

any(bool test(Hora element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
between(Hora rangeStart, Hora rangeEnd) → List<Hora>
Gets all occurrences within a date range.
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → Hora
Returns the indexth element.
inherited
every(bool test(Hora element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Hora element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(Hora element), {Hora orElse()?}) → Hora
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Hora element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Hora> other) → Iterable<Hora>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Hora element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
groupByDay() → Map<String, List<Hora>>

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Groups dates by day.
groupByMonth() → Map<String, List<Hora>>

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Groups dates by month.
groupByYear() → Map<int, List<Hora>>

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Groups dates by year.
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(Hora element), {Hora orElse()?}) → Hora
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(Hora e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
matches(Hora date) → bool
Checks if a date matches this recurrence pattern.
next(Hora current) → Hora?
Generates the next occurrence after the given date.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
occurrence(int n) → Hora?
Gets the nth occurrence (0-indexed).
reduce(Hora combine(Hora value, Hora element)) → Hora
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(Hora element), {Hora orElse()?}) → Hora
The single element that satisfies test.
inherited
skip(int count) → Iterable<Hora>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Hora element)) → Iterable<Hora>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<Hora>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Hora element)) → Iterable<Hora>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<Hora>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<Hora>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(Hora element)) → Iterable<Hora>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
withinRange(Hora start, Hora end) → Iterable<Hora>

Available on Iterable<Hora>, provided by the HoraIterableMinMaxExt extension

Gets dates that fall within a range.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

custom({required Hora start, required Hora? generator(Hora current), Hora? end, int? count}) → Recurrence
Creates a custom recurrence with a generator function.
daily({required Hora start, Hora? end, int? count, int interval = 1, Set<int>? excludeWeekdays}) → Recurrence
Creates a daily recurrence.
monthly({required Hora start, Hora? end, int? count, int interval = 1, int? dayOfMonth, int? weekdayOrdinal, int? weekday}) → Recurrence
Creates a monthly recurrence.
validateCount(int? count) → void
validateInterval(int interval) → void
validateWeekdays(Iterable<int> weekdays, {required String field}) → void
weekly({required Hora start, Hora? end, int? count, int interval = 1, Set<int> daysOfWeek = const {DateTime.monday}}) → Recurrence
Creates a weekly recurrence.
yearly({required Hora start, Hora? end, int? count, int interval = 1}) → Recurrence
Creates a yearly recurrence.