RelativeTimeDiff class

Represents a detailed breakdown of time difference.

Constructors

RelativeTimeDiff({required int years, required int months, required int days, required int hours, required int minutes, required int seconds, required bool isFuture})
const

Properties

days → int
final
hashCode → int
The hash code for this object.
no setterinherited
hours → int
final
isFuture → bool
final
minutes → int
final
months → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → int
final
totalDays → int
Gets the total days.
no setter
totalHours → int
Gets the total hours.
no setter
totalMinutes → int
Gets the total minutes.
no setter
totalSeconds → int
Gets the total seconds.
no setter
years → int
final

Methods

format({bool showAll = false}) → String
Formats as a human-readable string.
formatCompact() → String
Formats as a compact string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited