RelativeTimeThresholds class

Thresholds for determining which unit to use in relative time.

Constructors

RelativeTimeThresholds({int seconds = 44, int minutes = 44, int hours = 21, int days = 25, int months = 10})
const

Properties

days → int
Days before switching to "a month ago".
final
hashCode → int
The hash code for this object.
no setterinherited
hours → int
Hours before switching to "a day ago".
final
minutes → int
Minutes before switching to "an hour ago".
final
months → int
Months before switching to "a year ago".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → int
Seconds before switching to "a minute ago".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

strict → const RelativeTimeThresholds
Strict thresholds for more precise output.