TimePrecision enum

Represents different levels of time precision.

Inheritance
Available extensions

Values

year → const TimePrecision

Year precision.

quarter → const TimePrecision

Quarter precision.

month → const TimePrecision

Month precision.

week → const TimePrecision

Week precision.

day → const TimePrecision

Day precision.

hour → const TimePrecision

Hour precision.

minute → const TimePrecision

Minute precision.

second → const TimePrecision

Second precision.

millisecond → const TimePrecision

Millisecond precision.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
milliseconds → int

Available on TimePrecision, provided by the TimePrecisionExt extension

Gets the number of milliseconds in this precision unit.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toUnit → TemporalUnit

Available on TimePrecision, provided by the TimePrecisionExt extension

Converts this precision to a TemporalUnit.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TimePrecision>
A constant List of the values in this enum, in order of their declaration.