YearCalendar class

Represents a year calendar with months.

Properties

hashCode → int
The hash code for this object.
no setterinherited
months → List<MonthCalendar>
All months in the year.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year → int
The year.
final

Methods

month(int m) → MonthCalendar
Gets a specific month (1-12).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited