HoraFormats class
Localized date format patterns.
These format patterns follow the dayjs convention for locale-specific date formatting. Each pattern name corresponds to a standard format:
| Name | Description | Example (en) |
|---|---|---|
lt |
Short time | "8:02 PM" |
lts |
Long time | "8:02:18 PM" |
l |
Short date | "08/16/2018" |
ll |
Long date | "August 16, 2018" |
lll |
Long date + time | "August 16, 2018 8:02 PM" |
llll |
Full date + time | "Thursday, August 16, 2018 8:02 PM" |
These are used with the localized format tokens (L, LT, LTS, etc.)
in the Hora.format method.
- Annotations
-
- @immutable
Constructors
Properties
- dateLong → String
-
Alias for ll - long date format.
no setter
- dateShort → String
-
Alias for l - short date format.
no setter
- dateTimeFull → String
-
Alias for llll - full date with weekday and time.
no setter
- dateTimeLong → String
-
Alias for lll - long date with time.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- l → String
-
Short date format: "08/16/2018"
final
- ll → String
-
Long date format: "August 16, 2018"
final
- lll → String
-
Long date with time format: "August 16, 2018 8:02 PM"
final
- llll → String
-
Full date with time format: "Thursday, August 16, 2018 8:02 PM"
final
- lt → String
-
Short time format: "8:02 PM"
final
- lts → String
-
Long time format with seconds: "8:02:18 PM"
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeLong → String
-
Alias for lts - long time format with seconds.
no setter
- timeShort → String
-
Alias for lt - short time format.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited