CalendarConfig class

Configuration for calendar formatting.

Constructors

CalendarConfig({String sameDay = '[Today at] LT', String nextDay = '[Tomorrow at] LT', String nextWeek = 'dddd [at] LT', String lastDay = '[Yesterday at] LT', String lastWeek = '[Last] dddd [at] LT', String sameElse = 'L'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lastDay String
Format for yesterday.
final
lastWeek String
Format for dates within the last week.
final
nextDay String
Format for next day.
final
nextWeek String
Format for dates within the next week.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameDay String
Format for same day.
final
sameElse String
Format for all other dates.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultConfig → const CalendarConfig
Default configuration.