CalendarExt extension
Extension providing calendar functionality for Hora.
- on
Properties
-
daysOfMonth
→ List<
Hora> -
Available on Hora, provided by the CalendarExt extension
Gets all days in the current month.no setter -
daysOfYear
→ List<
Hora> -
Available on Hora, provided by the CalendarExt extension
Gets all days in the current year.no setter
Methods
-
calendar(
{Hora? referenceDate, CalendarConfig config = CalendarConfig.defaultConfig}) → String -
Available on Hora, provided by the CalendarExt extension
Formats this date in calendar style relative to a reference date. -
firstWeekdayInMonth(
int weekday) → Hora -
Available on Hora, provided by the CalendarExt extension
Gets the first occurrence of a weekday in the current month. -
isLongWeekend(
{bool isHoliday(Hora)?}) → bool -
Available on Hora, provided by the CalendarExt extension
Checks if this is part of a "long" weekend (3+ consecutive non-working days). -
lastWeekdayInMonth(
int weekday) → Hora -
Available on Hora, provided by the CalendarExt extension
Gets the last occurrence of a weekday in the current month. -
monthCalendar(
{int firstDayOfWeek = DateTime.monday}) → MonthCalendar -
Available on Hora, provided by the CalendarExt extension
Generates a calendar for the current month. -
nthWeekdayInMonth(
int weekday, int n) → Hora? -
Available on Hora, provided by the CalendarExt extension
Gets the nth occurrence of a weekday in the current month. -
yearCalendar(
{int firstDayOfWeek = DateTime.monday}) → YearCalendar -
Available on Hora, provided by the CalendarExt extension
Generates a calendar for the entire year.